#!/bin/sh

replace_lang() {
	if [ "$user" = "root" ]; then
		org_file="/etc/X11/xdm/kdmrc"
		new_file="/etc/X11/xdm/kdmrc.new"
		lang=`grep ^Language $org_file 2>/dev/null`
		if [ ! -z $lang ]; then
			sed "s/$lang/Language=$1/" $org_file > $new_file
			mv -f $new_file $org_file
		fi
	fi
}

replace_codepage() {
	SMBVER=`rpm -q --qf '%{version}\n' samba-common|head -n1`
	# we will modify smb.conf only for Asianux's version
	# for unknow version, we will do nothing.
	if [ "$SMBVER" = "3.0.14a" -o "$SMBVER" = "3.0.20b" ]; then
		if [ -f ~/.smb/smb.conf ]; then
			eval 'sed -i "s/CP.../$1/g" ~/.smb/smb.conf'
			sed -i 's/unix.*charset.*/unix charset = UTF-8/g' ~/.smb/smb.conf
	        	sed -i 's/display.*charset.*/display charset = UTF-8/g' ~/.smb/smb.conf
		fi
	fi
}

HEIGHT=15
DIALOG=`which dialog`
if [ -z $DIALOG ]; then
	echo "dialog not found in the system."
	exit 5
fi

user=`whoami`
if [ "$user" != "root" ]; then
	HOMEDIR=`/usr/bin/getent passwd $user | /bin/cut -d: -f6`
	if [ -z $HOMEDIR || -d "$HOMEDIR" ]; then
		$DIALOG --title "Error!" --msgbox "Home directory not found!" 0 0
		exit 5
	fi
	FILE=$HOMEDIR/.i18n
else
	FILE=/etc/sysconfig/i18n
fi

if [ -f "/etc/asianux-release" ]; then
        grep -q "Asianux release 1.0" /etc/asianux-release 2>/dev/null
        if [ $? -eq 0 ]; then
		$DIALOG --title "Please slect locale of your preference:" --clear \
			--radiolist "" $HEIGHT 50 7 \
			"English (en_US.UTF-8)" "" ON \
			"Simplified Chinese (zh_CN.GB18030)" "" off \
			"Japanese (ja_JP.eucJP)" "" off \
			"Japanese (ja_JP.SJIS)" "" off \
			"Japanese (ja_JP.UTF-8)" "" off \
			"Korean (ko_KR.eucKR)" "" off \
			"Korean (ko_KR.UTF-8)" "" off 2>/tmp/test.tmp.$$
		retval=$?
        else
		$DIALOG --title "Please slect locale of your preference:" --clear \
			--radiolist "" $HEIGHT 50 8 \
			"English (en_US.UTF-8)" "" ON \
			"Simplified Chinese (zh_CN.GB18030)" "" off \
			"Traditional Chinese (zh_TW.big5)" "" off \
			"Japanese (ja_JP.eucJP)" "" off \
			"Japanese (ja_JP.SJIS)" "" off \
			"Japanese (ja_JP.UTF-8)" "" off \
			"Korean (ko_KR.eucKR)" "" off \
			"Korean (ko_KR.UTF-8)" "" off 2>/tmp/test.tmp.$$
		retval=$?
        fi
else
	$DIALOG --title "Error!" --msgbox "asianux-release not installed properly!" 0 0
	exit 5
fi

choice=`cat /tmp/test.tmp.$$ | sed "s/'//g"`
rm -f /tmp/test.tmp.$$

case $retval in
0)
	case $choice in
	"English (en_US.UTF-8)")
		cat > $FILE <<EOF
LANG="en_US.UTF-8"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="latarcyrheb-sun16"
EOF
		replace_lang "en_US.UTF-8"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Simplified Chinese (zh_CN.GB18030)")
		cat > $FILE <<EOF
LANG="zh_CN.GB18030"
LANGUAGE="zh_CN.GB18030:zh_CN.GB2312:zh_CN"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "zh_CN.GB18030"
		replace_codepage "CP936"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Traditional Chinese (zh_TW.big5)")
		cat > $FILE <<EOF
LANG="zh_TW.big5"
LANGUAGE="zh_TW.big5:zh_TW"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "zh_TW.big5"
		replace_codepage "CP950"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.eucJP)")
		cat > $FILE <<EOF
LANG="ja_JP.eucJP"
LANGUAGE="ja_JP.eucJP:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ja_JP.eucJP"
		replace_codepage "CP932"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.SJIS)")
		cat > $FILE <<EOF
LANG="ja_JP.SJIS"
LANGUAGE="ja_JP.SJIS:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ja_JP.SJIS"
		replace_codepage "CP932"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.UTF-8)")
		cat > $FILE <<EOF
LANG="ja_JP.UTF-8"
LANGUAGE="ja_JP.UTF-8:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
EOF
		replace_lang "ja_JP.UTF-8"
		replace_codepage "CP932"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Korean (ko_KR.eucKR)")
		cat > $FILE <<EOF
LANG="ko_KR.eucKR"
LANGUAGE="ko_KR.eucKR:ko_KR"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ko_KR.eucKR"
		replace_codepage "CP949"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Korean (ko_KR.UTF-8)")
		cat > $FILE <<EOF
LANG="ko_KR.UTF-8"
LANGUAGE="ko_KR.UTF-8:ko_KR"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
EOF
		replace_lang "ko_KR.UTF-8"
		replace_codepage "CP949"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	*)
		$DIALOG --title "Error!" --msgbox "Please selece a language!" 0 0
		exit -1
		;;
	esac
	;;
1)
	$DIALOG --title "Information!" --msgbox "Cancel pressed." 0 0
	;;
255)
	$DIALOG --title "Information!" --msgbox "ESC pressed." 0 0
	;;
*)
	;;
esac
