#!/usr/bin/env python

import gtk
import gtk.glade
import os
import locale
import signal
import commands
import gettext

TRUE  = 1
FALSE = 0

domain = 'asianux-locale'
gettext.bindtextdomain(domain, '/usr/share/locale')
gettext.textdomain(domain)
gtk.glade.bindtextdomain(domain, '/usr/share/locale')
_ = gettext.gettext

params = [
          ["en_US.UTF-8", "",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "latarcyrheb-sun16", "", "en_US", _("English (en_US.UTF-8)")],
          ["ja_JP.eucJP", "ja_JP.eucJP:ja_JP",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "8859-15", "ja_JP", _("Japanese (ja_JP.eucJP)")],
          ["ja_JP.SJIS", "ja_JP.SJIS:ja_JP",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "8859-15", "ja_JP", _("Japanese (ja_JP.SJIS)")],
          ["ja_JP.UTF-8", "ja_JP.UTF-8:ja_JP",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "", "ja_JP", _("Japanese (ja_JP.UTF-8)")],
          ["ko_KR.eucKR", "ko_KR.eucKR:ko_KR",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "8859-15", "ko_KR", _("Korean (ko_KR.eucKR)")],
	  ["ko_KR.UTF-8", "ko_KR.UTF-8:ko_KR",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "", "ko_KR", _("Korean (ko_KR.UTF-8)")],
          ["zh_CN.GB18030", "zh_CN.GB18030:zh_CN.GB2312:zh_CN",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "8859-15", "zh_CN", _("Simplified Chinese (zh_CN.GB18030)")],
	  ["zh_TW.big5", "zh_TW.big5:zh_TW",
	   "en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko",
	   "lat0-sun16", "8859-15", "zh_TW", _("Traditional Chinese (zh_TW.big5)")]
         ]

jp_default = 3
ko_default = 4
cn_default = 6
tw_default = 7

fname = '/usr/share/asianux-locale/asianux-locale.glade'

remove_tw = FALSE
if os.system('/bin/grep -q \'Asianux release 1.0\' /etc/asianux-release 2>/dev/null') == 0:
    params.pop(tw_default)
    remove_tw = TRUE
    jp_default = 1


class Asianux_Locale:

    def disp_info_dialog(self, str):
	dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
				   type=gtk.MESSAGE_INFO,
				   buttons=gtk.BUTTONS_OK,
				   message_format=str)
	dialog.set_position(gtk.WIN_POS_CENTER)
	dialog.run()
	dialog.destroy()

    def disp_err_dialog(self, str):
	dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
				   type=gtk.MESSAGE_ERROR,
				   buttons=gtk.BUTTONS_OK,
				   message_format=str)
	dialog.set_position(gtk.WIN_POS_CENTER)
	ret = dialog.run()
	dialog.destroy()
	return ret

    def on_delete_event(self, window, event=None):
	gtk.main_quit()

    def on_system_toggled(self, window):
	self.update_system = TRUE

    def on_user_toggled(self, window):
	self.update_system = FALSE

    def on_combo_changed(self, window):
	index = 0
	tmp = self.entry.get_text()
	(stat, locale) = commands.getstatusoutput('/bin/echo \"' +  tmp + \
			'\" | /bin/cut -d\\( -f2 | /bin/cut -d\\) -f1')
	for i in range(len(params)):
	    if params[i][0] == locale:
		index = i
		break
	self.index = index

    def on_apply_clicked(self, window):
	target = ''
	if self.update_system:
	    target = self.system.get_label()
	    self.replace_kdmrc()
	else:
	    target = self.user.get_label()
	str = ''
	if params[self.index][0] != '':
	    str = "LANG=\\\"" + params[self.index][0] + "\\\"\\\\n"
	if params[self.index][1] != '':
	    str = str + "LANGUAGE=\\\"" + params[self.index][1] + "\\\"\\\\n"
	if params[self.index][2] != '':
	    str = str + "SUPPORTED=\\\"" + params[self.index][2] + "\\\"\\\\n"
	if params[self.index][3] != '':
	    str = str + "SYSFONT=\\\"" + params[self.index][3] + "\\\"\\\\n"
	if params[self.index][4] != '':
	    str = str + "SYSFONTACM=\\\"" + params[self.index][4] + "\\\"\\\\n"
	if str != '':
	    (stat, f) = commands.getstatusoutput('/bin/echo -e ' + str + ' > ' + target)
	    if stat == 0:
		self.disp_info_dialog(_('Successfully updated file.\n') + target + '\n\n' + \
			 _('Please logout once and login again to reflect the changes.\n'))
	    else:
		self.disp_err_dialog(f)
	else:
	    self.disp_err_dialog(_('Nothing to be updated.\n'))
	self.replace_codepage()

    def replace_codepage(self):
	(stat, SMBVER) = commands.getstatusoutput("rpm -q --qf '%{version}\n' samba-common|head -n1")
	if stat == 0:
	    if (SMBVER == "3.0.14a") or (SMBVER == "3.0.20b"):
		if params[self.index][5] == "zh_CN":
		    codepage = "CP936"
		elif params[self.index][5] == "zh_TW":
		    codepage = "CP950"
		elif params[self.index][5] == "ja_JP":
		    codepage = "CP932"
		elif params[self.index][5] == "ko_KR":
		    codepage = "CP949"
		
		(stat, tmp) = commands.getstatusoutput('sed -i "s/CP.../' + codepage + '/g" ~/.smb/smb.conf')
		(stat, tmp) = commands.getstatusoutput('sed -i "s/unix.*charset.*/unix charset = UTF-8/g" ~/.smb/smb.conf')
	        (stat, tmp) = commands.getstatusoutput('sed -i "s/display.*charset.*/display charset = UTF-8/g" ~/.smb/smb.conf')


    def replace_kdmrc(self):
	org_file = "/etc/X11/xdm/kdmrc"
	new_file = "/etc/X11/xdm/kdmrc.bak"
	(stat, str) = commands.getstatusoutput('/bin/grep ^Language= ' + \
		      org_file)
	if stat == 0:
	    (stat, tmp) = commands.getstatusoutput('/bin/sed \"s/' + \
			  str + "/Language=" + params[self.index][5] + \
			  "/\" " + org_file + " > " + new_file)
	    if stat == 0:
		(stat, tmp) = commands.getstatusoutput('mv -f ' + \
			      new_file + ' ' + org_file)

    def __init__(self):
	self.xml = gtk.glade.XML(fname, 'asianux-locale', domain)
	self.xml.signal_autoconnect(self)
	self.system = self.xml.get_widget('system_button')
	self.user = self.xml.get_widget('user_button')
	self.apply = self.xml.get_widget('apply_button')
	self.entry = self.xml.get_widget('combo_entry')
	self.index = 0
	self.update_system = TRUE
	myid = os.getuid()
	user_editable = TRUE
	if myid != 0 and os.geteuid != 0:
	    self.user.set_active(TRUE)
	    self.system.set_sensitive(FALSE)
	    self.update_system = FALSE
	(stat, f1) = commands.getstatusoutput('/usr/bin/getent passwd ' + str(myid))
	if stat != 0:
	    self.user.set_sensitive(FALSE)
	    user_editable = FALSE
	(stat, f2) = commands.getstatusoutput('/bin/echo ' + f1 + ' | /bin/cut -d: -f6')
	if (stat != 0) or (f2 == ''):
	    self.user.set_sensitive(FALSE)
	    user_editable = FALSE
	else:
	    self.user.set_label(f2 + '/.i18n')
	if not user_editable and not self.update_system:
	    self.disp_err_dialog(_('No file can be modified.\n'))
	    self.apply.set_sensitive(FALSE)
	combolist = self.xml.get_widget('combo-list1')
	comboitem = self.xml.get_widget('listitem1331')
	if remove_tw:
	    combolist.remove(comboitem)
	(lang, encoding) = locale.getlocale()
	if lang == 'ja_JP':
	    self.index = jp_default
	elif lang == 'ko_KR':
	    self.index = ko_default
	elif lang == 'zh_CN':
	    self.index = cn_default
	elif lang == 'zh_TW':
	    self.index = tw_default
	self.entry.set_text(params[self.index][6])


ax_locale = Asianux_Locale()
signal.signal(signal.SIGINT, gtk.main_quit)
gtk.main()
